@@ -1,103 +1,102 @@
-package Photography::EV;
+package Photography::EV 0.07 {
 
-use strict;
-use warnings;
-use 5.020000;
-use feature 'signatures';
-no warnings 'experimental::signatures';
-use base qw( Exporter );
-BEGIN {
-  eval q{ 
-    use POSIX qw( pow );
-  };
-  if($@)
-  {
-    *pow = sub ($x, $exponent)
+  use strict;
+  use warnings;
+  use 5.020000;
+  use experimental 'signatures';
+  use base qw( Exporter );
+  BEGIN {
+    eval q{ 
+      use POSIX qw( pow );
+    };
+    if($@)
     {
-      my $value = 1;
-      for(1..$exponent)
+      *pow = sub ($x, $exponent)
       {
-        $value *= $x;
+        my $value = 1;
+        for(1..$exponent)
+        {
+          $value *= $x;
+        }
+        $value;
       }
-      $value;
     }
   }
-}
-  
 
-our @EXPORT_OK = qw( ev aperture shutter_speed );
-our @EXPORT = @EXPORT_OK;
+  our @EXPORT_OK = qw( ev aperture shutter_speed );
+  our @EXPORT = @EXPORT_OK;
 
 # ABSTRACT: Calculate exposure value (EV)
-our $VERSION = '0.06'; # VERSION
 
 
-sub _round :prototype($)
-{
-  return $_[0] ? int($_[0] + $_[0]/abs($_[0]*2)) : 0;
-}
-
-sub _log2 :prototype($)
-{
-  return log($_[0])/log(2);
-}
-
-# returns the closest value in @$list to $exact
-# returns undef if @$list is empty
-sub _closest :prototype($$)
-{
-  my($exact, $list) = @_;
-  my $answer;
-  my $diff;
-  for(@$list)
+  sub _round :prototype($)
   {
-    my $maybe = abs($_ - $exact);
-    if((!defined $answer) || $maybe < $diff)
-    {
-      $answer = $_;
-      $diff = $maybe;
-    }
+    return $_[0] ? int($_[0] + $_[0]/abs($_[0]*2)) : 0;
   }
-  $answer;
-}
 
-my @apertures = qw(
-  1.0
-  1.4
-  2.8
-  4.0
-  5.6
-  8.0
-  11
-  16
-  22
-  32
-  45
-  64
-);
+  sub _log2 :prototype($)
+  {
+    return log($_[0])/log(2);
+  }
 
-my @times = (
-  (map { $_ * 60 } qw( 32 16 8 4 2 )),
-  (                qw( 60 30 15 8 4 2 1)),
-  (map { 1 / $_  } qw( 2 4 8 15 30 125 250 500 1000 2000 4000 8000 ))
-);
+  # returns the closest value in @$list to $exact
+  # returns undef if @$list is empty
+  sub _closest :prototype($$)
+  {
+    my($exact, $list) = @_;
+    my $answer;
+    my $diff;
+    for(@$list)
+    {
+      my $maybe = abs($_ - $exact);
+      if((!defined $answer) || $maybe < $diff)
+      {
+        $answer = $_;
+        $diff = $maybe;
+      }
+    }
+    $answer;
+  }
+
+  my @apertures = qw(
+    1.0
+    1.4
+    2.8
+    4.0
+    5.6
+    8.0
+    11
+    16
+    22
+    32
+    45
+    64
+  );
+
+  my @times = (
+    (map { $_ * 60 } qw( 32 16 8 4 2 )),
+    (                qw( 60 30 15 8 4 2 1)),
+    (map { 1 / $_  } qw( 2 4 8 15 30 125 250 500 1000 2000 4000 8000 ))
+  );
 
 
-sub ev ($aperture, $time)
-{
-  return _round _log2 $aperture*$aperture/$time;
-}
+  sub ev ($aperture, $time)
+  {
+    return _round _log2 $aperture*$aperture/$time;
+  }
 
 
-sub aperture ($ev, $time, $apertures = \@apertures )
-{
-  return _closest sqrt pow(2, $ev)*$time, $apertures;
-}
+  sub aperture ($ev, $time, $apertures = \@apertures )
+  {
+    return _closest sqrt pow(2, $ev)*$time, $apertures;
+  }
 
 
-sub shutter_speed ($ev, $aperture, $times = \@times )
-{
-  return _closest $aperture*$aperture/pow(2, $ev), $times;
+  sub shutter_speed ($ev, $aperture, $times = \@times )
+  {
+    return _closest $aperture*$aperture/pow(2, $ev), $times;
+  }
+
 }
 
 1;
@@ -114,7 +113,7 @@ Photography::EV - Calculate exposure value (EV)
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -187,12 +186,12 @@ This module requires Perl 5.20 or better.
 
 =over 4
 
-=item http://en.wikipedia.org/wiki/Exposure_value
+=item L<http://en.wikipedia.org/wiki/Exposure_value>
+
+=item L<Photography::DX>
 
 =back
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <plicease@cpan.org>
